use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
API
Adjustment
Component
FromBuilder
GDK
GdkQuartz
GdkWin32
GdkX11
Gtk3
GtkPackType
Helper
Intertangle
Mughal
Role
SizeRequest
Types
UI
UIFileFromPackageName
WindowID
X11
XInput
Zakariyya
lib
natively
zmughal
